@extends('layouts.app')

@section('head')
	<title>{{ $project->content->title }} | {{ env('APP_NAME') }}</title>
	<meta name="description" content="{{ $project->content->meta_description }}">

	<meta property="og:type" content="article" />
	<meta property="og:url" content="{{ route(trans('url.project'), [$project->content->slug, $project->id]) }}" />
	<meta property="og:title" content="{{ $project->content->title }}" />
	<meta property="og:image" content="{{ url('/img/uploads/' . $project->thumbnail) }}" />
	<meta property="og:description" content="{{ $project->content->meta_description }}" />
@endsection

@section('content')
	<section id="portfolioItem">
		<div class="portfolio-item__title fade--{{ $project->color }}">
			<h1>{{ $project->content->name }}.</h1>
		</div>
		<div class="container">
			<div id="carouselPortfolio" class="carousel slide" data-ride="carousel">
			  	<div class="carousel-inner">
			    	<div class="carousel-item active">
			      		<img src="/img/uploads/{{ $project->thumbnail }}" class="img-fluid wow slideInUp">
			    	</div>
			  	</div>
			</div>
		</div>
	</section>

	<section id="PortfolioItemDescription">
		<div class="container">
			<div class="row">
				<div class="col text-center">
					<h2 class="subtitle--green h4 wow slideInUp"><strong>{{ $project->content->name }}</strong></h2>
					<div class="text--gray wow slideInUp">{!! $project->content->description !!}</div>
				</div>
			</div>
		</div>
		<div class="container-fluid">
			<div class="row">
				@php($i = 1)
				@foreach ($project->images as $image)
					@if ($i <= 3)
						<div class="col-md-4" style="margin-bottom: 30px;">
							<img src="/img/uploads/{{ $image->name }}" class="img-fluid lazy wow zoomIn" data-wow-delay=".{{ $i*3 }}s">
						</div>
					@endif
					@php($i++)
				@endforeach
			</div>
		</div>
	</section>

	<section id="PortfolioItemCaption">
		<div class="container">
			<div class="row">
				<div class="col wow slideInUp">
					<h4 class="PortfolioItem__caption"> <img src="/img/c-left.jpg"> {{ $project->content->caption }} <img src="/img/c-right.jpg"> </h4>
				</div>
			</div>
			<div class="row">
				<div class="col">
					<div class="portfolioItem__hr"></div>
				</div>
			</div>
			<div class="row">
				<div class="col-md-6 wow slideInLeft">
					<h4 class="subtitle--green"><strong>{{ trans('commons.challenge') }}</strong></h4>
					<div class="text--gray">{!! $project->content->description_2 !!}</div>
				</div>
				<div class="col-md-6 wow slideInRight">
					<div id="carouselPortfolio2" class="carousel slide" data-ride="carousel">
					  	<div class="carousel-inner">
					  		@php($i = 1)
							@foreach ($project->images as $image)
								@if ($i >= 4)
									<div class="carousel-item @if($i==4) active @endif">
										<img src="/img/uploads/{{ $image->name }}" class="img-fluid lazy">
							    	</div>
								@endif
								@php($i++)
							@endforeach
					  	</div>
					  	<a href="#carouselPortfolio2" class="carousel-control-prev" data-slide="prev"><img src="/img/a-left.png" style="width: 40px"></a>
		  				<a href="#carouselPortfolio2" class="carousel-control-next" data-slide="next"><img src="/img/a-right.png" style="width: 40px"></a>
					</div>
				</div>
			</div>
			<div class="row navBarProjects">
				@if (isset($prev_project->content->slug))
					<div class="col-md-1 wow slideInLeft">
						<a href="{{ route(trans('url.project'), [$prev_project->content->slug, $prev_project->id]) }}#portfolioItem"><img src="/img/a-left.jpg" class="img-fluid" style="margin-top: -15px;"></a>
					</div>
					<div class="col-md-4 text-right wow slideInLeft">
						<p class="subtitle--wrapper"><a href="{{ route(trans('url.project'), [$prev_project->content->slug, $prev_project->id]) }}#portfolioItem" class="h4 subtitle--black" data-caption="{{ $prev_project->content->name }}"> <span></span> {{ $prev_project->content->name }} </a></p>
						<p style="color: #848484;font-family: 'Montserrat';font-size: 15px;line-height: 30px;margin-bottom: 0;">{{ $prev_project->start }} - {{ $prev_project->end }}</p>
					</div>
				@else
					<div class="col-md-1 wow slideInLeft"></div>
					<div class="col-md-4 text-right wow slideInLeft"><p class="subtitle--wrapper"></p>
					</div>
				@endif

				<div class="col-md-2 text-center wow slideInUp">
					<img src="/img/linear-vertical.png" class="img-fluid">
				</div>

				@if (isset($next_project->content->slug))
					<div class="col-md-4 text-left wow slideInRight">
						<p class="subtitle--wrapper"><a href="{{ route(trans('url.project'), [$next_project->content->slug, $next_project->id]) }}#portfolioItem" class="h4 subtitle--black" data-caption="{{ $next_project->content->name }}"> <span></span> {{ $next_project->content->name }} </a></p>
						<p style="color: #848484;font-family: 'Montserrat';font-size: 15px;line-height: 30px;margin-bottom: 0;">{{ $next_project->start }} - {{ $next_project->end }}</p>
					</div>
					<div class="col-md-1 wow slideInRight">
						<a href="{{ route(trans('url.project'), [$next_project->content->slug, $next_project->id]) }}#portfolioItem"><img src="/img/a-right.jpg" class="img-fluid" style="margin-top: -15px;"></a>
					</div>
				@endif
			</div>
			<div class="row" style="margin-top: 40px;margin-bottom: -50px;">
				<div class="col text-center">
					<p class="wow slideInUp" style="font-family: 'Montserrat';font-size: 15px;line-height: 30px;"><a style="color: #848484;" href="{{ route(trans('url.portfolio')) }}">{{ trans('commons.all_projects') }} <img src="/img/icon-all.jpg" style="margin-top: -5px; margin-left: 5px;"></a></p>
				</div>
			</div>
		</div>
	</section>
@endsection


@section('scripts')
<script>
	$(document).ready(function(){
		$('.subtitle--black').each (function(){
			var caption = $(this).data('caption');
			$(this).children('span').html(caption + '<br>');
		});
	});
</script>
@endsection