<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

date_default_timezone_set('America/Cancun');
App::setLocale(\App\Settings::getLanguage());


//Commons
Route::group(['domain' => env('DOMAIN_WEBSITE')], function () {

  	Route::get('/', function () {
        return redirect()->to('/es');
    });

    Route::get('thanks', [
  	   'uses' => 'PagesController@thanks',
  	   'as' => 'thanks'
  	]);

  	Route::post('subscribers/store', [
     'uses' => 'SubscribersController@store',
     'as' => 'subscribers.store'
    ]);

    Route::post('inquires/store', [
     'uses' => 'InquiresController@store',
     'as' => 'inquires.store'
    ]);

    Route::get('settings/change', [
        'uses' => 'PagesController@settings',
        'as' => 'settings.update'
    ]);

    Route::get('url/alternate', [
        'uses' => 'PagesController@getAlternate',
        'as' => 'url.alternate'
    ]);

});

//Spanish
Route::group(['domain' => env('DOMAIN_WEBSITE'), 'prefix' => 'es'], function () {

	Route::get('/', [
		'uses' => 'PagesController@home',
		'as' => 'home_es'
	]);

	Route::get('nosotros', [
		'uses' => function () { return view('about'); },
		'as' => 'about_es'
	]);

	Route::get('servicios', [
		'uses' => 'PagesController@services',
		'as' => 'services_es'
	]);

	Route::get('servicio/{slug}/{id}', [
		'uses' => 'PagesController@service',
		'as' => 'service_es'
	]);

	Route::get('proyectos', [
		'uses' => 'PagesController@projects',
		'as' => 'portfolio_es'
	]);

	Route::get('proyecto/{slug}/{id}', [
		'uses' => 'PagesController@project',
		'as' => 'project_es'
	]);

	Route::get('contacto', [
		'uses' => function () { return view('contact'); },
		'as' => 'contact_es'
	]);

	Route::get('blog', [
		'uses' => 'PagesController@getBlog',
		'as' => 'blog_es'
	]);

	Route::get('blog/{slug}/{id}', [
		'uses' => 'PagesController@getPost',
		'as' => 'post_es'
	]);

});


//English
Route::group(['domain' => env('DOMAIN_WEBSITE'), 'prefix' => 'en'], function () {

	Route::get('/', [
		'uses' => 'PagesController@home',
		'as' => 'home_en'
	]);

	Route::get('about-us', [
		'uses' => function () { return view('about'); },
		'as' => 'about_en'
	]);

	Route::get('services', [
		'uses' => 'PagesController@services',
		'as' => 'services_en'
	]);

	Route::get('service/{slug}/{id}', [
		'uses' => 'PagesController@service',
		'as' => 'service_en'
	]);

	Route::get('portfolio', [
		'uses' => 'PagesController@projects',
		'as' => 'portfolio_en'
	]);

	Route::get('project/{slug}/{id}', [
		'uses' => 'PagesController@project',
		'as' => 'project_en'
	]);

	Route::get('contacto', [
		'uses' => function () { return view('contact'); },
		'as' => 'contact_en'
	]);

	Route::get('blog', [
		'uses' => 'PagesController@getBlog',
		'as' => 'blog_en'
	]);

	Route::get('blog/{slug}/{id}', [
		'uses' => 'PagesController@getPost',
		'as' => 'post_en'
	]);

});


// Authentication routes...

Auth::routes();

Route::get('logout', 'Auth\LoginController@logout');

//Admin routes...

Route::group(['prefix' => 'admin', 'middleware' => 'auth'], function () {

  	Route::get('/', function () {
    	return view('admin.welcome');
  	});

	Route::resource('services', 'admin\ServiceController');
	Route::resource('projects', 'admin\ProjectController');  	
	Route::resource('blog', 'admin\BlogController');
	Route::resource('subscribers', 'admin\SubscriberController');  	
	Route::resource('inquiries', 'admin\InquireController');
	Route::resource('users', 'admin\UsersController');

	Route::resource('services.images', 'admin\ServiceImagesController');
	Route::resource('projects.images', 'admin\ProjectImagesController');
	Route::resource('blog.images', 'admin\BlogImagesController');

});